function rbf = getWen(d, k)
% GETWEN returns a Wendland RBF.
%   rbf = GETWEN(d, k) returns a function handle representing the Wendland 
%   kernel of smoothness k in dimension d, where k is an integer in [0, 4].
%   The handled function is in the form
%       rbf(ep, r)
%   where ep > 0 is the shape parameter and r > 0 is the radial variable.
%
%   See also getRbf


switch k
    case 0
        p = '1';
    case 1
        p = '(l + 1) * r + 1';
    case 2
        p = '(l + 3) * (l + 1) * r .^ 2 + 3 * (l + 2) * r + 3';
    case 3
        p = '(l + 5) * (l + 3) * (l + 1) * r .^ 3 + (45 + 6 * l * (l + 6)) * r .^ 2 + (15 * (l + 3)) * r + 15';
    case 4
        p = '(l + 7) * (l + 5) * (l + 3) * (l + 1) * r .^ 4 + (5 * (l + 4) * (21 + 2 * l * (8 + l))) * r .^ 3 + (45 * (14 + l * (l + 8))) * r .^ 2 + (105 * (l + 4)) * r + 105';
    otherwise
        error('Order between 0 and 4!')
end

l = floor(d / 2) + k + 1;
c = factorial(l + 2 * k) / factorial(l);
e = l + k;

p = ['max(1 - r, 0) .^ e .* (', p, ') / c']; 

p = strrep(p, 'l', num2str(l));
p = strrep(p, 'c', num2str(c));
p = strrep(p, 'e', num2str(e));
p = strrep(p, 'r', '(ep * r)');

p = ['@(ep, r) ', p]; 

rbf = str2func(p);

end








