function plotPoints(X, color, titleString)
% PLOTPOINTS Plots points in arbitrary dimension.
%   PLOTPOINTS(X) plots the N d-dimensional points contained in the Nxd
%   matrix X. If d>3, a PCA is applied to the matrix and only the first
%   three dimensions are plotted.
%   Color specifications and a title can be passed as inputs.

if ~exist('color', 'var')
    color = '.';
end
if ~exist('titleString', 'var')
    titleString = [];
end

d = size(X, 2);

if d == 1
    plot(X, 0 * X, color, 'markersize', 12)
elseif d == 2
    plot(X(:, 1), X(:, 2), color, 'markersize', 12)
elseif d == 3
    plot3(X(:, 1), X(:, 2), X(:, 3), color, 'markersize', 12)
else
    [U, ~] = svd(X' * X);
    X = X * U(:, 1 : 3);
    plot3(X(:, 1), X(:, 2), X(:, 3), color, 'markersize', 12)
end
title(titleString)
axis equal

end

